/* -*- Mode: C++; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */
#ifndef nsLocaleCID_h__
#define nsLocaleCID_h__

// {F25F74F1-FB59-11d3-A9F2-00203522A03C}
#define NS_OS2LOCALE_CID			 \
{ 0xf25f74f1, 0xfb59, 0x11d3,                  \
{ 0xa9, 0xf2, 0x0, 0x20, 0x35, 0x22, 0xa0, 0x3c }}

#define NS_OS2LOCALE_CONTRACTID "@mozilla.org/locale/os2-locale;1"

#endif // nsLocaleCID_h__

